#!/usr/local/bin/perl
# parse_test.pl - Tests the DBIWrapper::XMLParser module.
use strict;
use DBIWrapper::XMLParser;

my $version = "1.1";
my $errStr = "(parse_test) - Error:";

my $resultSetObj = DBIWrapper::XMLParser->new(file => "test2.xml");

my $xmlString = <<"DATA";
<?xml version="1.0" encoding="ISO-8859-1"?>
<resultset version="1.1">
  <select sql="SELECT * FROM test_tb WHERE value LIKE '%&quot;test&quot;%' ORDER BY name, value" plug="''"/>
  <status result="Ok"/>
  <rows numRows="1" columns="0">
    <row name="complex" value="This is a &quot;test&quot;!\\nI 'wonder' what DBI
will do with\\nthis &amp;embeded &lt;stuff&gt;!?\\n"/>
  </rows>
</resultset>
DATA

my $xmlString2 = <<"DATA";
<?xml version="1.0" encoding="ISO-8859-1"?>
<resultset version="1.1">
  <select sql="SELECT invalid FROM test_tb" plug="''"/>
  <status result="Error" error="DBIWrapper::readXML - DBIWrapper::read - Eval of execute failed!&lt;br&gt;\\nError = 'DBD::Pg::st execute failed: ERROR:  Attribute 'invalid' not found at DBIWrapper.pm line 407.\\n'.&lt;br&gt;\\nsql='SELECT invalid FROM test_tb'.&lt;br&gt;\\nplug=''.&lt;br&gt;\\n"/>
  <rows numRows="0" columns="0"/>
</resultset>
DATA

#my $resultSetObj = DBIWrapper::XMLParser->new(string => $xmlString2);
#my $resultSetObj = DBIWrapper::XMLParser->new(file => 'test.xml', string => $xmlString);

my $dataObj = undef;

eval { $dataObj = $resultSetObj->parse; };
if ($@)
{
  die "$errStr  Eval failed: $@\n";
}

my @result = $dataObj->isValid();
if (!$result[0])
{
  print "ResultSet File not valid!\n\n";
  print join("\n", $result[1]) . "\n";
  exit 0;
}

# test the actual data as we implement different parsing code.
my $test = "html";  # values are 'text', 'html' or 'xml'.

if ($test eq "html")
{
  print "<html>\n<head>\n<title>parse_test</title>\n</head>\n<body>\n";
  print $dataObj->displayData(style => "html");
  print "</body>\n</html>\n";
}
elsif ($test eq "text")
{
  print $dataObj->displayData;
}
elsif ($test eq "xml")
{
  print $dataObj->generateXML;
}
